@@ -31,7 +31,7 @@ mesh_to_poly <- function(lng_center, lat_center, lng_error, lat_error, ...) {
     sf::st_as_text()
 }
 
-#' @title Identifer to mesh size
+#' @title Identifier to mesh size
 #' @description Returns a unit object of mesh size for the given number.
 #' @inheritParams mesh_to_coords
 #' @inheritParams meshcode_vector
@@ -213,7 +213,7 @@ bind_meshpolys <- function(meshcode) {
   meshcode %>%
     fine_separate() %>%
     unique() %>%
-    export_meshes()
+    export_meshes(.keep_class = TRUE)
 }
 
 code_reform <- function(jis_code) {
