@@ -3,7 +3,7 @@ context("convert to mesh code")
 # Order 1 -----------------------------------------------------------------
 test_that("from latitude and longitude to mesh 1", {
   res <- 
-    coords_to_mesh(133, 34, mesh_size = 80.000)
+    coords_to_mesh(133, 34, to_mesh_size = 80.000)
   expect_true(is_meshcode(res))
   expect_equal(
     nchar(vctrs::field(res, "mesh_code")),
@@ -18,7 +18,7 @@ test_that("from latitude and longitude to mesh 1", {
 # Order 2 -----------------------------------------------------------------
 test_that("from latitude and longitude to mesh 2", {
   res <- 
-    coords_to_mesh(133.875, 34.583333, mesh_size = 10.000)
+    coords_to_mesh(133.875, 34.583333, to_mesh_size = 10.000)
   expect_true(is_meshcode(res))
   expect_equal(
     nchar(vctrs::field(res, "mesh_code")),
@@ -29,7 +29,7 @@ test_that("from latitude and longitude to mesh 2", {
 # Order 3 -----------------------------------------------------
 test_that("from latitude and longitude to mesh 2", {
   res <- 
-    coords_to_mesh(133.9125, 34.65, mesh_size = 1.000)
+    coords_to_mesh(133.9125, 34.65, to_mesh_size = 1.000)
   expect_true(is_meshcode(res))
   expect_equal(
     nchar(vctrs::field(res, "mesh_code")),
@@ -40,16 +40,25 @@ test_that("from latitude and longitude to mesh 2", {
                coords_to_mesh(133.9125, 34.65))
 })
 
+
+# Irregular ---------------------------------------------------------------
+test_that("Error", {
+  res <-
+    expect_warning(.coord2mesh(NA, NA, to_mesh_size = 1))
+  expect_equal(res, NA_character_)
+})
+
+
 # Separete Mesh: harf -----------------------------------------
 test_that("Separete to harf mesh", {
   res <- 
     coords_to_mesh(139.301255, 35.442788,
-                        mesh_size = 5.0)
+                   to_mesh_size = 5.0)
   expect_equal(res, 
                meshcode(5339121))
   res <- 
     coords_to_mesh(139.301255, 35.442788,
-                        mesh_size = 0.500)
+                   to_mesh_size = 0.500)
   expect_true(is_meshcode(res))
   expect_equal(
     nchar(vctrs::field(res, "mesh_code")),
@@ -61,7 +70,7 @@ test_that("Separete to harf mesh", {
 # Separete Mesh: quarter ---------------------------------------
 test_that("Separete to quarter mesh", {
   res <- 
-    coords_to_mesh(133.9125, 34.65, mesh_size = 0.250)
+    coords_to_mesh(133.9125, 34.65, to_mesh_size = 0.250)
   expect_true(is_meshcode(res))
   expect_equal(
     nchar(vctrs::field(res, "mesh_code")),
@@ -69,22 +78,22 @@ test_that("Separete to quarter mesh", {
   expect_equal(res, 
                meshcode("5133778222"))
   res <- 
-    coords_to_mesh(139.310654, 35.442893, mesh_size = 0.250)
+    coords_to_mesh(139.310654, 35.442893, to_mesh_size = 0.250)
   expect_equal(res, 
                meshcode("5339123422"))
   res <-
-    coords_to_mesh(139.301706, 35.448767, mesh_size = 0.250)
+    coords_to_mesh(139.301706, 35.448767, to_mesh_size = 0.250)
   expect_equal(res, 
                meshcode("5339123433"))
   res <- 
-    coords_to_mesh(139.311340, 35.449011, mesh_size = 0.250)
+    coords_to_mesh(139.311340, 35.449011, to_mesh_size = 0.250)
   expect_equal(res,
                meshcode("5339123444"))
 })
 
 test_that("125m", {
   res <- 
-    coords_to_mesh(133.9125, 34.65, mesh_size = 0.125)
+    coords_to_mesh(133.9125, 34.65, to_mesh_size = 0.125)
   expect_equal(
     nchar(vctrs::field(res, "mesh_code")), 
     11L)
@@ -92,6 +101,16 @@ test_that("125m", {
                meshcode("51337782222"))
 })
 
+test_that("100m", {
+  res <- 
+    coords_to_mesh(139.71475, 35.70078, to_mesh_size = 0.1)
+  expect_is(res, "subdiv_meshcode")
+  expect_equal(
+    res,
+    meshcode("5339454701", .type = "subdivision")
+  )
+})
+
 # sfg object --------------------------------------------------------------
 test_that("Input XY sfg", {
   skip_if_not_installed("sf")
@@ -101,7 +120,7 @@ test_that("Input XY sfg", {
                meshcode("53394547"))
   res <-
     coords_to_mesh(geometry = sf::st_point(c(139.71475, 35.70078)),
-                   mesh_size = 0.500)
+                   to_mesh_size = 0.500)
   expect_equal(res, 
                meshcode("533945471"))
   res <-
@@ -116,10 +135,11 @@ test_that("Input XY sfg", {
     administration_mesh(code = "08220", to_mesh_size = 1)
   suppressWarnings(res$geometry <- sf::st_centroid(res$geometry))
   res$meshcode_copy <-
-    coords_to_mesh(mesh_size = 1.000, geometry = res$geometry)
+    coords_to_mesh(to_mesh_size = 1.000, geometry = res$geometry)
   suppressWarnings(res$geometry <-
                      sf::st_centroid(res$geometry))
-  res$check <- all.equal(res$meshcode, res$meshcode_copy)
+  res$check <- all.equal(res$meshcode, 
+                         as.character(res$meshcode_copy))
   expect_equal(sum(res$check == FALSE), 0)
 })
 
