@@ -11,6 +11,10 @@ test_that("typeof", {
   expect_equal(sf::st_crs(
     export_mesh(sample(meshcode_set(80), 1)))$epsg, 
                4326) # nolint
+  res <- 
+    export_meshes(c(51324305, 51381043),
+                  .keep_class = TRUE)
+  expect_is(res$meshcode, "meshcode")
 })
 
 test_that("Convert include meshcode dataframe to sf", {
@@ -23,3 +27,11 @@ test_that("Convert include meshcode dataframe to sf", {
   expect_s3_class(res, "sf")
   expect_named(res, c("id", "meshcode", "geometry"))
 })
+
+test_that("Create mesh grid", {
+  res <-
+    st_mesh_grid(513404944, to_mesh_size = 0.5)
+  expect_s3_class(res, "sfc")
+  expect_length(res, 4L)
+  expect_error(st_mesh_grid(543352, to_mesh_size = 0.5))
+})
